summaryrefslogtreecommitdiff
path: root/depot_gui.c
diff options
context:
space:
mode:
authorbelugas <belugas@openttd.org>2006-10-02 00:28:31 +0000
committerbelugas <belugas@openttd.org>2006-10-02 00:28:31 +0000
commit2c45339e0ae0fa0b466b725eb2280a16a5b167d5 (patch)
tree824c32c54efb62eb8db1cd43c94dbe8c28a30b9a /depot_gui.c
parent21591b5219a99a9d798c43dc2d89e7d00475f7cd (diff)
downloadopenttd-2c45339e0ae0fa0b466b725eb2280a16a5b167d5.tar.xz
(svn r6612) -Codechange: Use accessors for hidden_state.
Another step toward merging XTDwidget. The only two files not converted (window.h and widget.c) will be done at the very last commit)
Diffstat (limited to 'depot_gui.c')
-rw-r--r--depot_gui.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/depot_gui.c b/depot_gui.c
index a72887212..83554a89d 100644
--- a/depot_gui.c
+++ b/depot_gui.c
@@ -71,7 +71,7 @@ static const byte widget_moves[] = {
/* Widget array for all depot windows.
* If a widget is needed in some windows only (like train specific), add it for all windows
* and use w->hidden_state in ShowDepotWindow() to remove it in the windows where it should not be
* Keep the widget numbers in sync with the enum or really bad stuff will happen!!! */
/* When adding widgets, place them as you would place them for the ship depot and define how you want it to move in widget_moves[]
@@ -968,8 +968,8 @@ void ShowDepotWindow(TileIndex tile, byte type)
+ (type == VEH_Train ? 1 : w->hscroll.cap); // number of boxes in each row. Trains always have just one
if (type != VEH_Train) {
- SETBIT(w->hidden_state, DEPOT_WIDGET_H_SCROLL);
- SETBIT(w->hidden_state, DEPOT_WIDGET_SELL_CHAIN);
+ HideWindowWidget(w, DEPOT_WIDGET_H_SCROLL);
+ HideWindowWidget(w, DEPOT_WIDGET_SELL_CHAIN);
}
/* Move the widgets to their right locations */
@@ -71,7 +71,7 @@ static const byte widget_moves[] = {
/* Widget array for all depot windows.
* If a widget is needed in some windows only (like train specific), add it for all windows
- * and use w->hidden_state in ShowDepotWindow() to remove it in the windows where it should not be
+ * and use HideWindowWidget in ShowDepotWindow() to remove it in the windows where it should not be
* Keep the widget numbers in sync with the enum or really bad stuff will happen!!! */
/* When adding widgets, place them as you would place them for the ship depot and define how you want it to move in widget_moves[]